==> ZenTaoPMS.max2.0.rc1.php7.0.zip: zentaopms/module/workflowaction/ext/config/flow.php <==
<?php
$config->workflowaction->buildin = new stdclass();
$config->workflowaction->buildin->actions['product']     = array('browse', 'create', 'batchedit', 'edit', 'view', 'delete', 'close');
$config->workflowaction->buildin->actions['story']       = array('browse', 'create', 'batchcreate', 'batchedit', 'exporttemplate', 'import', 'showimport', 'edit', 'view', 'delete', 'close', 'activate', 'assignTo', 'review', 'change');
$config->workflowaction->buildin->actions['productplan'] = array('browse', 'create', 'batchedit', 'edit', 'view', 'delete');
$config->workflowaction->buildin->actions['release']     = array('browse', 'create', 'edit', 'view', 'delete');
$config->workflowaction->buildin->actions['project']     = array('browse', 'create', 'batchedit', 'edit', 'view', 'delete', 'close', 'activate', 'start', 'putoff', 'suspend');
$config->workflowaction->buildin->actions['task']        = array('browse', 'create', 'batchcreate', 'batchedit', 'exporttemplate', 'import', 'showimport', 'edit', 'view', 'delete', 'close', 'activate', 'assignTo', 'confirmStoryChange', 'start', 'finish', 'pause', 'restart', 'cancel');
$config->workflowaction->buildin->actions['build']       = array('browse', 'create', 'edit', 'view', 'delete');
$config->workflowaction->buildin->actions['bug']         = array('browse', 'create', 'batchcreate', 'batchedit', 'exporttemplate', 'import', 'showimport', 'edit', 'view', 'delete', 'close', 'activate', 'assignTo', 'confirmBug', 'resolve', 'batchconfirm', 'batchresolve');
$config->workflowaction->buildin->actions['testcase']    = array('browse', 'create', 'batchcreate', 'batchedit', 'exporttemplate', 'import', 'showimport', 'edit', 'view', 'delete', 'review');
$config->workflowaction->buildin->actions['testtask']    = array('browse', 'create', 'edit', 'view', 'delete', 'close', 'activate', 'start', 'block');
$config->workflowaction->buildin->actions['testsuite']   = array('browse', 'create', 'edit', 'view', 'delete');
$config->workflowaction->buildin->actions['caselib']     = array('browse', 'create', 'edit', 'view', 'delete');
$config->workflowaction->buildin->actions['feedback']    = array('browse', 'create', 'batchedit', 'edit', 'view', 'delete', 'close', 'assignTo', 'review', 'comment', 'admin', 'adminview');

$config->workflowaction->buildin->opens['product']['close']           = 'modal';
$config->workflowaction->buildin->opens['product']['delete']          = 'none';
$config->workflowaction->buildin->opens['project']['suspend']         = 'modal';
$config->workflowaction->buildin->opens['project']['activate']        = 'modal';
$config->workflowaction->buildin->opens['project']['close']           = 'modal';
$config->workflowaction->buildin->opens['project']['putoff']          = 'modal';
$config->workflowaction->buildin->opens['project']['start']           = 'modal';
$config->workflowaction->buildin->opens['project']['delete']          = 'none';
$config->workflowaction->buildin->opens['story']['activate']          = 'modal';
$config->workflowaction->buildin->opens['story']['close']             = 'modal';
$config->workflowaction->buildin->opens['story']['assignTo']          = 'modal';
$config->workflowaction->buildin->opens['story']['exporttemplate']    = 'modal';
$config->workflowaction->buildin->opens['story']['showimport']        = 'modal';
$config->workflowaction->buildin->opens['story']['import']            = 'modal';
$config->workflowaction->buildin->opens['story']['delete']            = 'none';
$config->workflowaction->buildin->opens['productplan']['delete']      = 'none';
$config->workflowaction->buildin->opens['release']['delete']          = 'none';
$config->workflowaction->buildin->opens['task']['assignTo']           = 'modal';
$config->workflowaction->buildin->opens['task']['confirmStoryChange'] = 'none';
$config->workflowaction->buildin->opens['task']['start']              = 'modal';
$config->workflowaction->buildin->opens['task']['finish']             = 'modal';
$config->workflowaction->buildin->opens['task']['pause']              = 'modal';
$config->workflowaction->buildin->opens['task']['restart']            = 'modal';
$config->workflowaction->buildin->opens['task']['close']              = 'modal';
$config->workflowaction->buildin->opens['task']['activate']           = 'modal';
$config->workflowaction->buildin->opens['task']['cancel']             = 'modal';
$config->workflowaction->buildin->opens['task']['delete']             = 'none';
$config->workflowaction->buildin->opens['task']['exporttemplate']     = 'modal';
$config->workflowaction->buildin->opens['task']['showimport']         = 'modal';
$config->workflowaction->buildin->opens['task']['import']             = 'modal';
$config->workflowaction->buildin->opens['build']['delete']            = 'none';
$config->workflowaction->buildin->opens['bug']['assignTo']            = 'modal';
$config->workflowaction->buildin->opens['bug']['confirmBug']          = 'modal';
$config->workflowaction->buildin->opens['bug']['resolve']             = 'modal';
$config->workflowaction->buildin->opens['bug']['activate']            = 'modal';
$config->workflowaction->buildin->opens['bug']['close']               = 'modal';
$config->workflowaction->buildin->opens['bug']['delete']              = 'none';
$config->workflowaction->buildin->opens['bug']['exporttemplate']      = 'modal';
$config->workflowaction->buildin->opens['bug']['showimport']          = 'modal';
$config->workflowaction->buildin->opens['bug']['import']              = 'modal';
$config->workflowaction->buildin->opens['bug']['batchconfirm']        = 'none';
$config->workflowaction->buildin->opens['bug']['batchresolve']        = 'none';
$config->workflowaction->buildin->opens['testcase']['delete']         = 'none';
$config->workflowaction->buildin->opens['testcase']['exporttemplate'] = 'modal';
$config->workflowaction->buildin->opens['testcase']['showimport']     = 'modal';
$config->workflowaction->buildin->opens['testcase']['import']         = 'modal';
$config->workflowaction->buildin->opens['testtask']['start']          = 'modal';
$config->workflowaction->buildin->opens['testtask']['activate']       = 'modal';
$config->workflowaction->buildin->opens['testtask']['close']          = 'modal';
$config->workflowaction->buildin->opens['testtask']['block']          = 'modal';
$config->workflowaction->buildin->opens['testtask']['delete']         = 'none';
$config->workflowaction->buildin->opens['testsuite']['delete']        = 'none';
$config->workflowaction->buildin->opens['caselib']['delete']          = 'none';
$config->workflowaction->buildin->opens['feedback']['review']         = 'modal';
$config->workflowaction->buildin->opens['feedback']['assignTo']       = 'modal';
$config->workflowaction->buildin->opens['feedback']['close']          = 'modal';
$config->workflowaction->buildin->opens['feedback']['comment']        = 'modal';
$config->workflowaction->buildin->opens['feedback']['delete']         = 'none';

$config->workflowaction->buildin->layouts['product']['view']  = 'side';
$config->workflowaction->buildin->layouts['story']['edit']    = 'side';
$config->workflowaction->buildin->layouts['story']['view']    = 'side';
$config->workflowaction->buildin->layouts['project']['view']  = 'side';
$config->workflowaction->buildin->layouts['task']['edit']     = 'side';
$config->workflowaction->buildin->layouts['task']['view']     = 'side';
$config->workflowaction->buildin->layouts['bug']['edit']      = 'side';
$config->workflowaction->buildin->layouts['bug']['view']      = 'side';
$config->workflowaction->buildin->layouts['testcase']['edit'] = 'side';
$config->workflowaction->buildin->layouts['testcase']['view'] = 'side';
$config->workflowaction->buildin->layouts['testtask']['view'] = 'side';
$config->workflowaction->buildin->layouts['feedback']['view'] = 'side';

$config->workflowaction->default->types['batchconfirm'] = 'batch';
$config->workflowaction->default->types['batchresolve'] = 'batch';

$config->workflowaction->noNoticeActions[] = 'batchcreate';
$config->workflowaction->noNoticeActions[] = 'batchedit';
$config->workflowaction->noNoticeActions[] = 'batchassign';

==> ZenTaoPMS.max2.2.php7.0.zip: zentaopms/module/workflowaction/ext/config/flow.php <==
<?php
$config->workflowaction->buildin = new stdclass();
$config->workflowaction->buildin->actions['product']     = array('browse', 'create', 'batchedit', 'edit', 'view', 'delete', 'close');
$config->workflowaction->buildin->actions['story']       = array('browse', 'create', 'batchcreate', 'batchedit', 'exporttemplate', 'import', 'showimport', 'edit', 'view', 'delete', 'close', 'activate', 'assignTo', 'review', 'change');
$config->workflowaction->buildin->actions['productplan'] = array('browse', 'create', 'batchedit', 'edit', 'view', 'delete');
$config->workflowaction->buildin->actions['release']     = array('browse', 'create', 'edit', 'view', 'delete');
$config->workflowaction->buildin->actions['program']     = array('browse', 'create', 'edit', 'view', 'delete', 'close', 'activate', 'start', 'suspend');
$config->workflowaction->buildin->actions['project']     = array('browse', 'create', 'batchedit', 'edit', 'view', 'delete', 'close', 'activate', 'start', 'suspend');
$config->workflowaction->buildin->actions['execution']   = array('task', 'create', 'batchedit', 'edit', 'view', 'delete', 'close', 'activate', 'start', 'putoff', 'suspend');
$config->workflowaction->buildin->actions['task']        = array('browse', 'create', 'batchcreate', 'batchedit', 'exporttemplate', 'import', 'showimport', 'edit', 'view', 'delete', 'close', 'activate', 'assignTo', 'confirmStoryChange', 'start', 'finish', 'pause', 'restart', 'cancel');
$config->workflowaction->buildin->actions['build']       = array('browse', 'create', 'edit', 'view', 'delete');
$config->workflowaction->buildin->actions['bug']         = array('browse', 'create', 'batchcreate', 'batchedit', 'exporttemplate', 'import', 'showimport', 'edit', 'view', 'delete', 'close', 'activate', 'assignTo', 'confirmBug', 'resolve', 'batchconfirm', 'batchresolve');
$config->workflowaction->buildin->actions['testcase']    = array('browse', 'create', 'batchcreate', 'batchedit', 'exporttemplate', 'import', 'showimport', 'edit', 'view', 'delete', 'review');
$config->workflowaction->buildin->actions['testtask']    = array('browse', 'create', 'edit', 'view', 'delete', 'close', 'activate', 'start', 'block');
$config->workflowaction->buildin->actions['testsuite']   = array('browse', 'create', 'edit', 'view', 'delete');
$config->workflowaction->buildin->actions['caselib']     = array('browse', 'create', 'edit', 'view', 'delete');
$config->workflowaction->buildin->actions['feedback']    = array('browse', 'create', 'batchedit', 'edit', 'view', 'delete', 'close', 'assignTo', 'review', 'comment', 'admin', 'adminview');

$config->workflowaction->buildin->opens['product']['close']           = 'modal';
$config->workflowaction->buildin->opens['product']['delete']          = 'none';
$config->workflowaction->buildin->opens['program']['suspend']         = 'modal';
$config->workflowaction->buildin->opens['program']['activate']        = 'modal';
$config->workflowaction->buildin->opens['program']['close']           = 'modal';
$config->workflowaction->buildin->opens['program']['start']           = 'modal';
$config->workflowaction->buildin->opens['program']['delete']          = 'none';
$config->workflowaction->buildin->opens['project']['suspend']         = 'modal';
$config->workflowaction->buildin->opens['project']['activate']        = 'modal';
$config->workflowaction->buildin->opens['project']['close']           = 'modal';
$config->workflowaction->buildin->opens['project']['start']           = 'modal';
$config->workflowaction->buildin->opens['project']['delete']          = 'none';
$config->workflowaction->buildin->opens['execution']['suspend']       = 'modal';
$config->workflowaction->buildin->opens['execution']['activate']      = 'modal';
$config->workflowaction->buildin->opens['execution']['close']         = 'modal';
$config->workflowaction->buildin->opens['execution']['putoff']        = 'modal';
$config->workflowaction->buildin->opens['execution']['start']         = 'modal';
$config->workflowaction->buildin->opens['execution']['delete']        = 'none';
$config->workflowaction->buildin->opens['story']['activate']          = 'modal';
$config->workflowaction->buildin->opens['story']['close']             = 'modal';
$config->workflowaction->buildin->opens['story']['assignTo']          = 'modal';
$config->workflowaction->buildin->opens['story']['exporttemplate']    = 'modal';
$config->workflowaction->buildin->opens['story']['showimport']        = 'modal';
$config->workflowaction->buildin->opens['story']['import']            = 'modal';
$config->workflowaction->buildin->opens['story']['delete']            = 'none';
$config->workflowaction->buildin->opens['productplan']['delete']      = 'none';
$config->workflowaction->buildin->opens['release']['delete']          = 'none';
$config->workflowaction->buildin->opens['task']['assignTo']           = 'modal';
$config->workflowaction->buildin->opens['task']['confirmStoryChange'] = 'none';
$config->workflowaction->buildin->opens['task']['start']              = 'modal';
$config->workflowaction->buildin->opens['task']['finish']             = 'modal';
$config->workflowaction->buildin->opens['task']['pause']              = 'modal';
$config->workflowaction->buildin->opens['task']['restart']            = 'modal';
$config->workflowaction->buildin->opens['task']['close']              = 'modal';
$config->workflowaction->buildin->opens['task']['activate']           = 'modal';
$config->workflowaction->buildin->opens['task']['cancel']             = 'modal';
$config->workflowaction->buildin->opens['task']['delete']             = 'none';
$config->workflowaction->buildin->opens['task']['exporttemplate']     = 'modal';
$config->workflowaction->buildin->opens['task']['showimport']         = 'modal';
$config->workflowaction->buildin->opens['task']['import']             = 'modal';
$config->workflowaction->buildin->opens['build']['delete']            = 'none';
$config->workflowaction->buildin->opens['bug']['assignTo']            = 'modal';
$config->workflowaction->buildin->opens['bug']['confirmBug']          = 'modal';
$config->workflowaction->buildin->opens['bug']['resolve']             = 'modal';
$config->workflowaction->buildin->opens['bug']['activate']            = 'modal';
$config->workflowaction->buildin->opens['bug']['close']               = 'modal';
$config->workflowaction->buildin->opens['bug']['delete']              = 'none';
$config->workflowaction->buildin->opens['bug']['exporttemplate']      = 'modal';
$config->workflowaction->buildin->opens['bug']['showimport']          = 'modal';
$config->workflowaction->buildin->opens['bug']['import']              = 'modal';
$config->workflowaction->buildin->opens['bug']['batchconfirm']        = 'none';
$config->workflowaction->buildin->opens['bug']['batchresolve']        = 'none';
$config->workflowaction->buildin->opens['testcase']['delete']         = 'none';
$config->workflowaction->buildin->opens['testcase']['exporttemplate'] = 'modal';
$config->workflowaction->buildin->opens['testcase']['showimport']     = 'modal';
$config->workflowaction->buildin->opens['testcase']['import']         = 'modal';
$config->workflowaction->buildin->opens['testtask']['start']          = 'modal';
$config->workflowaction->buildin->opens['testtask']['activate']       = 'modal';
$config->workflowaction->buildin->opens['testtask']['close']          = 'modal';
$config->workflowaction->buildin->opens['testtask']['block']          = 'modal';
$config->workflowaction->buildin->opens['testtask']['delete']         = 'none';
$config->workflowaction->buildin->opens['testsuite']['delete']        = 'none';
$config->workflowaction->buildin->opens['caselib']['delete']          = 'none';
$config->workflowaction->buildin->opens['feedback']['review']         = 'modal';
$config->workflowaction->buildin->opens['feedback']['assignTo']       = 'modal';
$config->workflowaction->buildin->opens['feedback']['close']          = 'modal';
$config->workflowaction->buildin->opens['feedback']['comment']        = 'modal';
$config->workflowaction->buildin->opens['feedback']['delete']         = 'none';

$config->workflowaction->buildin->layouts['product']['view']  = 'side';
$config->workflowaction->buildin->layouts['story']['edit']    = 'side';
$config->workflowaction->buildin->layouts['story']['view']    = 'side';
$config->workflowaction->buildin->layouts['project']['view']  = 'side';
$config->workflowaction->buildin->layouts['task']['edit']     = 'side';
$config->workflowaction->buildin->layouts['task']['view']     = 'side';
$config->workflowaction->buildin->layouts['bug']['edit']      = 'side';
$config->workflowaction->buildin->layouts['bug']['view']      = 'side';
$config->workflowaction->buildin->layouts['testcase']['edit'] = 'side';
$config->workflowaction->buildin->layouts['testcase']['view'] = 'side';
$config->workflowaction->buildin->layouts['testtask']['view'] = 'side';
$config->workflowaction->buildin->layouts['feedback']['view'] = 'side';

$config->workflowaction->default->types['batchconfirm'] = 'batch';
$config->workflowaction->default->types['batchresolve'] = 'batch';

$config->workflowaction->noNoticeActions[] = 'batchcreate';
$config->workflowaction->noNoticeActions[] = 'batchedit';
$config->workflowaction->noNoticeActions[] = 'batchassign';
